<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Libraries\Util;

use Appweb\Produto;
use Appweb\CategoriaProduto;
use Appweb\Fornecedor;

class ProdutosController extends Controller
{
    
    private $produto;

    public function __construct(Produto $produto)
    {
        $this->produto = $produto;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        
        if ($request->has('busca')) {
            $busca = Produto::where('referencia', 'like', '%'.$request->busca.'%')
                ->orWhere('descricao', 'like', '%'.$request->busca.'%')
                ->orderBy('descricao')
                ->paginate(15);
        } else {
            $busca = Produto::orderBy('descricao')
                ->paginate(15);
        }

        return view('pages.cadastros.produtos.index')
            ->with("modulo", "Produtos")
            ->with('busca', $busca);
    
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        $categorias = CategoriaProduto::lists('descricao', 'codigo')->toArray();
        return view('pages.cadastros.produtos.form', compact('fornecedores', 'categorias'))
            ->with("modulo", "Produtos")
            ->with('legenda', 'Produto - Novo');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $regras = [
            'referencia'=>'required|max:13|unique:produtos', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            ];
        $mensagens = [
            'referencia.required'=>'Preencha o Código', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            ];
        $this->validate($request,$regras,$mensagens);
        $this->produto->create([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>($request->has('categoria')) ? $request->categoria : null,
            'valor'=>Util::toFloat($request->valor),
            'valor2'=>Util::toFloat($request->valor2), 
            'valorprazo'=>Util::toFloat($request->valorprazo), 
            'valorprazo2'=>Util::toFloat($request->valorprazo2),
            'estoque'=>($request->has('estoque')) ? $request->estoque : 0,
            ]);
        return redirect('cadastros/produtos');
    }

    public function produtoNovo(Request $request) 
    {
        $regras = [
            'referencia'=>'required|max:13|unique:produtos', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            ];
        $mensagens = [
            'referencia.required'=>'Preencha a Referência', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            ];
        $this->validate($request,$regras,$mensagens);
        $produto = $this->produto->create([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'valor'=>toFloat($request->valor),
            ]);
        return $produto;
        
    }

    public function listarProdutos(Request $request)
    {
        
        if ($request->has('busca')) {
            $produtos = $this->produto->select("produtos.*")
                ->where('produtos.referencia', '=', $request->busca)
                ->orWhere('descricao', 'like', '%' . $request->busca . '%')
                ->get();
        } else {
            $produtos = $this->produto->select("produtos.*")
                ->join('pedidos_itens', 'produtos.referencia', '=', 'pedidos_itens.referencia')
                ->limit(20)
                ->groupby('produtos.referencia')
                ->get();
        }
        // dd($produtos);
        return view('pages.partials.listar-produtos', compact('produtos'));

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $produto = $this->produto->find($id);
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        $categorias = CategoriaProduto::lists('descricao', 'codigo')->toArray();
        return view('pages.cadastros.produtos.form', compact('produto', 'categorias', 'fornecedores'))
            ->with("modulo", "Produtos")
            ->with('legenda', 'Edição');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id, Request $request)
    {
        $regras = [
            'referencia'=>'required|max:13', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            ];
        $mensagens = [
            'referencia.required'=>'Preencha o Código', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            ];
        $this->validate($request,$regras,$mensagens);
        $produto = $this->produto->find($id);
        $produto->update([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>($request->has('categoria')) ? $request->categoria : null,
            'valor'=>Util::toFloat($request->valor),
            'valor2'=>Util::toFloat($request->valor2), 
            'valorprazo'=>Util::toFloat($request->valorprazo), 
            'valorprazo2'=>Util::toFloat($request->valorprazo2),
            'estoque'=>($request->has('estoque')) ? $request->estoque : 0,
            ]);
        return redirect('cadastros/produtos');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->produto->find($id)->delete();
        return redirect()->back();
    }
}
